use crate::{app_error::AppError, services};
use serde::Serialize;
#[tauri::command]
pub fn greet(name: &str) -> String {
    format!("Hello, {}! You've been greeted from Rust!", name)
}
#[derive(Serialize)]
pub struct PeNodeTreeData {
    title: String,
    key: String,
    children: Vec<PeNodeTreeData>,
}

// TODO: 获取PE节点树的JSON数据
#[tauri::command]
pub fn command_get_file_pe_node_tree_data() -> Result<Vec<PeNodeTreeData>, AppError> {
    // 1. 如果全局内存映射句柄为空，则返回错误
    if unsafe { services::GLOBAL_MEMMAP_HANDLE.is_none() } {
        return Err(AppError::NoFileOpened);
    }
    // 从文件路径中获取文件名
    let file_name: &str = unsafe {
        let file_path = services::GLOBAL_FILE_PATH.as_ref().unwrap();
        let file_name = std::path::Path::new(file_path).file_name().unwrap();
        file_name.to_str().unwrap()
    };
    let result = PeNodeTreeData {
        title: format!("文件: {}", file_name),
        key: "fileName".to_string(),
        children: vec![
            PeNodeTreeData {
                title: "DOS 头部".to_string(),
                key: "DOS Header".to_string(),
                children: vec![], // 空数组表示没有子节点
            },
            PeNodeTreeData {
                title: "NT 头部".to_string(),
                key: "NT Headers".to_string(),
                children: vec![
                    PeNodeTreeData {
                        title: "文件头部".to_string(),
                        key: "File Header".to_string(),
                        children: vec![],
                    },
                    PeNodeTreeData {
                        title: "可选头部".to_string(),
                        key: "Optional Header".to_string(),
                        children: vec![PeNodeTreeData {
                            title: "数据目录".to_string(),
                            key: "Data Directories".to_string(),
                            children: vec![],
                        }],
                    },
                ],
            },
            PeNodeTreeData {
                title: "节区头部".to_string(),
                key: "Section Headers".to_string(),
                children: vec![],
            },
        ],
    };
    Ok(vec![result])
}

// 命令，打开文件
#[tauri::command]
pub fn command_open_file(file_path: &str) -> Result<(), AppError> {
    unsafe {
        services::GLOBAL_MEMMAP_HANDLE = Some(services::file::mmap_mut_file(file_path)?);
        services::GLOBAL_FILE_PATH = Some(file_path.to_string());
        Ok(())
    }
}
