import styles from "./MainPage.module.scss";
import { useEffect, useState } from "react";
import { Layout, Flex, Button } from "antd";
import { listen } from "@tauri-apps/api/event";
import { invoke } from "@tauri-apps/api/core";
const { Content } = Layout;
import { SaveOutlined } from "@ant-design/icons";
import SiderTree from "../components/side_tree/SideTree";
import DosHeader from "../components/DosHeader/DosHeader";

export default function MainPage() {
  const [treeData, setTreeData] = useState([]);
  const [filePath, setFilePath] = useState("");

  useEffect(() => {
    const unlisten = listen<{ paths: Array<string> }>(
      "tauri://drag-drop",
      (event) => {
        const filePath = event.payload.paths[0];
        console.log("file path:", filePath);
        setFilePath(filePath);
        invoke("command_open_file", { filePath }).then(() => {
          invoke("command_get_file_pe_node_tree_data").then((res) => {
            console.log("tree nodes:", res);
            setTreeData(res as any);
          });
        });
      }
    );
    return () => {
      unlisten.then((f) => f());
    };
  }, []);

  return (
    <Layout className={styles.mainLayout}>
      <Flex className={styles.header}>
        <Button type="primary" icon={<SaveOutlined></SaveOutlined>}>
          保存
        </Button>
      </Flex>
      <Flex>
        <Flex className={styles.sider}>
          <SiderTree
            treeData={treeData}
            defaultSelectedKey={treeData[0]?.key || ""}
          />
        </Flex>
        <Content>
          <DosHeader></DosHeader>
        </Content>
      </Flex>
    </Layout>
  );
}
